#++
point-segment.mu - several utilities to "TeX-draw" a tree graph

resol2::Point       - append a point at given relative coordinates
resol2::Segment     - append a segment at given relative coordinates
resol2::AbsPoint    - append a point at given absolute coordinates
resol2::AbsSegment  - append a segement at given absolute coordinates
resol2::Putneighbors- draw the branches from a point (recursive, it iterates through
                           all the points)
++#

#++
all these functions either return without output; possible errors are due to
input mistakes.
++#


#++
resol2::Point(drawing,NName,coordx,coordy,h,v)

drawing         - name of the file (must be open) in which to append the point (a TeX-draw file)
NName           - text to write at 'the point location'
coordx,coordy   - relative coordinates at which to put the point
h,v             - horizontal and vertical displacement to locate the NName
++#

resol2::Point:=proc(drawing,NName,coordx,coordy,h,v)
# this procedure appends a point at (coordx,coordy)
RELATIVE TO THE CURRENT POSSITION!.
NEW POSSITION IS (oldx oldy)+(coordx coordy)!
to drawing, which is assumed to be a document
of the form
 \documentclass{???}\usepackage{texdraw}\begin{document}
 \begin{center}\begin{texdraw} ...
(or to be \input'ed into one complete (AMS)-(La)TeX document)
NOTE THE LACK OF "end's" #
	  local mydrawing,mypoint;
	begin
	  mydrawing:=drawing:mypoint:="":
	  mypoint:="\\rmove (",coordx:
	  mypoint:=mypoint ," ", coordy:
	  mypoint:=mypoint,") \\fcir f:0 r:2":
	  fprint(Unquoted,mydrawing,mypoint):
	  if not(NName="") then
	    fprint(Unquoted,mydrawing,"\\rmove (",h," ",v,")"," \\htext{",NName,"}",
		   " \\rmove(",-h," ",-v,")"):
	    end_if:
	  return:
	end_proc:

#++
resol2::AbsPoint(drawing,NName,coordx,coordy,h,v)

drawing         - name of the file (must be open) in which to append the point (a TeX-draw file)
NName           - text to write at 'the point location'
coordx,coordy   - absolute coordinates at which to put the point (i.e. no change of coord is done)
h,v             - horizontal and vertical displacement to locate the NName
++#


resol2::AbsPoint:=proc(drawing,NName,coordx,coordy,h,v)
# this procedure appends a point at (coordx,coordy)
(RELATIVE TO THE CURRENT POSSITION!.
CURRENT POSSITION IS UNTOUCHED (Abs)).
to drawing, which is assumed to be a document
of the form
 \documentclass{???}\usepackage{texdraw}\begin{document}
 \begin{center}\begin{texdraw} ...
(or to be \input'ed into one complete (AMS)-(La)TeX document)
NOTE THE LACK OF "end's" #
	  local mydrawing,mypoint;
	begin
	  mydrawing:=drawing:mypoint:="":
	  mypoint:="\\rmove (",coordx:mypoint:=mypoint ," ", coordy:mypoint:=mypoint,") \\fcir f:0 r:2":
	  fprint(Unquoted,mydrawing,mypoint):
	  if not(NName="") then
	    fprint(Unquoted,mydrawing,"\\rmove (",h," ",v,")"," \\htext{",NName,"}",
		   " \\rmove(",-h," ",-v,")"):
	  end_if:
	  fprint(Unquoted,mydrawing,"\\rmove (",-coordx," ",-coordy,")"):
	  return:
	end_proc:

#++
resol2::Segment(drawing,inx,iny,endx,endy,gray,label,labx,laby)

drawing         - name of the file (must be open) in which to append the point (a TeX-draw file)
inx,iny         - the starting point (relative to the current possition)
enx,endy        - the ending point (relative to inx,iny: i.e. in=(2,1) en=(1,0) draws a
                  segment from (2,1) to (3,1) )
gray            - graylevel (currently not implemented)
label           - label to put at the 'middle point'
labx,laby       - displacement to put the label, relative to the middlepoint of the segment
++#



resol2::Segment:=proc(drawing,inx,iny,endx,endy,gray,label,labx,laby)
# this procedure adds to "drawing" (see Point) a segment from (inx iny) to (endx endy)
RELATIVE TO THE CURRENT POSSITION!
NEW POSSITION IS (inx iny)+(endx endy)
with a label "label" at the center + (labx laby) #
	   local mydrawing,mysegment,middlex,middley;
	 begin
	   middlex:=endx/2.0:
	   middley:=endy/2.0:
	   mydrawing:=drawing:
	   mysegment:="":
	   mysegment:=mysegment,"\\rmove(",inx," ",iny,") \n":
	   mysegment:=mysegment,"\\rlvec(",middlex," ",middley,") \n":
	   if not(label="") then
	     mysegment:=mysegment,"\\rmove(",labx," ",laby,") \n":
	     mysegment:=mysegment,"\\htext{",label,"}\n":
	     mysegment:=mysegment,"\\rmove(",-labx," ",-laby,") \n":
	   end_if:
	   mysegment:=mysegment,"\\rlvec(",middlex," ",middley,")":# not newline bc. next fprint adds it #
	   fprint(Unquoted,mydrawing,mysegment):
	   return:
	 end_proc:


#++
resol2::AbsSegment(drawing,inx,iny,endx,endy,gray,label,labx,laby)

drawing         - name of the file (must be open) in which to append the point (a TeX-draw file)
inx,iny         - the starting point (relative to the current possition,
                  the current possition is left untouched (Abs) )
enx,endy        - the ending point (relative to inx,iny: i.e. in=(2,1) en=(1,0) draws a
                  segment from (2,1) to (3,1) )
gray            - graylevel (currently not implemented)
label           - label to put at the 'middle point'
labx,laby       - displacement to put the label, relative to the middlepoint of the segment
++#


resol2::AbsSegment:=proc(drawing,inx,iny,endx,endy,gray,label,labx,laby)
# this procedure adds to "drawing" (see Point) a segment from (inx iny) to (endx endy)
(RELATIVE TO THE CURRENT POSSITION!
NEW POSSITION IS UNTOUCHED Abs)
with a label "label" at the center + (labx laby) #
	   local mydrawing,mysegment,middlex,middley;
	 begin
	   middlex:=endx/2.0:
	   middley:=endy/2.0:
	   mydrawing:=drawing:
	   mysegment:="":
	   mysegment:=mysegment,"\\rmove(",inx," ",iny,") \n":
	   mysegment:=mysegment,"\\rlvec(",middlex," ",middley,") \n":
	   if not(label="") then
	     mysegment:=mysegment,"\\rmove(",labx," ",laby,") \n":
	     mysegment:=mysegment,"\\htext{",label,"}\n":
	     mysegment:=mysegment,"\\rmove(",-labx," ",-laby,") \n":
	   end_if:
	   mysegment:=mysegment,"\\rlvec(",middlex," ",middley,")":
	   fprint(Unquoted,mydrawing,mysegment):
	   fprint(Unquoted,mydrawing,"\\rmove( ",-endx," ",-endy,")"):
# not newline bc. next fprint adds it #
	   return:
	 end_proc:


#++
resol2::Putneighbors(drawing,inx,iny,endx,endy,gray,label,labx,laby)

drawing         - name of the file (must be open) in which to draw the graph (a TeX-draw file)
_graph          - the graph (a 'tree') to be drawn
_vertex         - the vertex at which to begin
depth           - this is an index on the length of the starting-segments: it increases, so that
                  the length decreases as (9/10)*length each time the procedure is called
++#


resol2::Putneighbors:=proc(drawing,_graph,_vertex,depth)
#  _graph is the graph minus the "already drawn" path  #
		local mydrawing,i,mylength,mylengthx,mylengthy,gr,
		vecin,vecin_number,mydepth,vert,
		anglocal,graylevel;
	      begin
		gr:=_graph:
		vert:=_vertex:
		mydepth:=depth:
		mydrawing:=drawing:
		Point(mydrawing,vert,0,0,0,2):
		vecin:=resol2::neighbors(vert,gr):
		if not(hastype(vecin,DOM_FLOAT)) then
		  vecin_number:=nops(vecin):
		  for i from 1 to vecin_number do
		  # we put the dummy 0+30,0-30 degrees opening. (version  1.0 :-)  #
		    anglocal:=0.0+(-1.0)^i*(60/vecin_number)*(i-1):
		    mylength:=eval(50.0*.9^depth):
		    mylengthx:=mylength*cos(anglocal+.0)+.0:
		    mylengthy:=mylength*sin(anglocal+.0)+.0:
		    if vecin[i]<0 then graylevel:=.5 else graylevel:=0: end_if:
		    resol2::Segment(mydrawing,0,0,mylengthx,mylengthy,graylevel,"",0,0):
		    resol2::Putneighbors(mydrawing,DelVertex(gr,vert),vecin[i],depth+1):
		    resol2::Segment(mydrawing,0,0,-mylengthx,-mylengthy,1,"",0,0):		    
		  end_for:
		end_if:
		return:
	      end_proc:






