#++
resol2::reduccd - the main one. reduce the singularities of a plane 1-form and
                  compute the separatrices (only the corresponding to non-dicritical
                  divisors).

resol2::reduccd(a, b, xx, yy, p, text,divisor,dm)

a,b       - polynomials in the variables "xx,yy" (which have to be passed as parameters)
            notice that there is -no- restriction on the field
xx,yy     - the variables in which a,b are polynomials
p         - I do not remember...
text      - useless
divisor   - the actual divisor under study (this is not really exact)
dm        - the highest divisor created up to now
++#

#++
resol2::reduccd - output

1)	     [[seq(resol2::COCIENTES[i],i=[$1..resol2::CONTADOR-1])],resol2::CONTADOR-1],
                                              resol2::GRAFO
                 
where:
resol2::COCIENTES   - list of the form
             [[c1,p1],<[c2,p2],...,[cn,pn]>]   n=resol2::CONTADOR-1

                      with
                       c1,...,cn    - quotient of eigenvalues of the 1st,...,n-th
                                      simple singularity appearing
                                      in the reduction of singularities of omega=a dx +b dy.
                       p1,...,pn    - type of point:
                          0  - regular, that is, it is not a crossing of irreducible comps of the divisor
                          1  - corner, i. e. a normal crossing of the divisor

resol2::CONTADOR-1  - number of simple singularities found

resol2::GRAFO       - domain::Network with the dual tree of the reduction of singularities

SPECIAL CASES

2)            ["d1"],resol2::GRAFO

this means that a dx +b dy is dicritic at (0,0) and has no singularities after one
blowing-up.

resol2::GRAFO       - is the 'singleton' graph, which has only on vertex and no edges
++#


#++
PLEASE NOTICE THAT resol2::reduccd USES SEVERAL GLOBAL VARIABLES

resol2::INF        - this variable is initially 0 (false), it is given the value 1 (true) when
                     the procedure has studied the point at infinity in the first blowing-up; that
                     is, the point corresponding to the line xx=0
resol2::GRAFO      - the dual graph of the resolution
resol2::COCIENTES  - the sequence of quotients of eigenvalues at the simple singularities and
                     the kind of singularity (0 means corner, 1 means regular (non-crossing) )
resol2::NUMDIVISOR - the highest value of the divisors we have created
resol2::CONTADOR   - the number of simple singularities found
resol2::SEP        - the number of separatrices
resol2::SEPARATRIX - the 'parametrization' of the separatrices

ALL THIS VARIABLES ARE INITIALIZED AS 'ZERO' (IN THEIR CORRESPONDING DOMAINS) IN resol2::reduccion
++#

#++
Concerning the global variables, the following is done:

resol2::INF        - is given the value 1 if the form a dx +b dy has a non-simple singularity at (0,0).
                     this 1 is put when reduccd 'studies' the point at infinity (corresponding to the
                     direction (xx=0) ) of the first divisor.

resol::GRAFO       - is added a vertex each time a divisor is created, and edges correpondign to
                     its location in the exceptional divisor

resol2::COCIENTES  - each time a simple singularity is found, we add [pi,ci] to this list, where
                     pi=0 if the point is not a crossing, and pi=1 if it is a crossing
                     ci= the quotient of eigenvalues of the linear part of omega at that point

resol2::NUMDIVISOR - this is a counter which increases in 1 each time a blowing-up is done

resol2::CONTADOR   - the number of simple singularities found +1

resol2::SEP        - the number of simple singularities which are not corners, that is, through which
                     a [possibly formal] separatrix passes

resol2::SEPARATRIX - the parametrization of the separatrices, with the coordinates corresponding to
                     the working-point, see resol2::SimpleSeparatrix. Mainly, the structure is
                        [xi(t),yi(t) <, "exact">] where xi(t) and yi(t) are polynomials in a
                                    variable "t". These
                                    polynomials are a parametrization of the i-th separatrix found.
                                    They are always adapted to the present coordinates. The string
                                    "exact" in the third place is added only when the parametrization
                                    is an exact solution.
++#

resol2::reduccd := proc(a, b, xx, yy, p, text,divisor,dm)
	     local
	     divv,trans2, ii, omegax2, omegay2, raices2, rraices2, trans, i,
	     separatrix_par, j, cociente,
	     inx, iny, autov, raices1, trans1, inicial, punto,nd, omega, omegax,ndd,minimo,
	     textito,omegay,uuu,vvv, x, y, mult, tt, texto,minim,Minim,sx,sy,sep_before,t,strange_thing;
# first of all, let us "args-"tize all  #
	   begin
	     textito:="";
	     cociente:=0:
	     autov:=[1,1,1];
	     ndd:=args(8): #  divisor we are studying  #
	     texto := args(6);
	     omegax := a;
	     omegay := b;
	     x := args(3);
	     y := args(4);
	     punto := args(5);
	     omega := omegax*Der(x) + omegay*Der(y);
	     divv:=divisor:
#next line to debug graph#
             userinfo(2,Edge(resol2::GRAFO));
	     #  compute the algebraic multiplicity  #
	     mult := min(ldegree(collect(omegax, [x, y]), [x, y]),
			 ldegree(collect(omegay, [x, y]), [x, y]));
	     inx := resol2::termino(mult, omegax, [x, y]); #  homogeneous part of a of degree mult  #
	     iny := resol2::termino(mult, omegay, [x, y]); #  ibid. of b  #
	     inicial := collect(simplify(expand(inx*x + iny*y)), [x, y]); #  tangent cone  #
             #  begins the dicritic case: tangent cone=0  #
	     if inicial = 0 then
#  blow-up. One form (omegax, omegay) for a chart of the divisor and 
another (omegax2, omegay2) for the other
these are the usual transformations 
it would be better to have a function for doing it,
but we leave it for version 3.0  #
      	       trans1 := subs(omega,Der(y) = tt*Der(x) + Der(x) + x*Der(tt));
	       trans1 := subs(trans1,y = x*tt + x);
	       trans1 := subs(trans1,tt = y);
	       trans := collect(simplify(expand(trans1)/x^(mult+1)),[Der(x), Der(y)]);
	       trans := simplify(trans);
	       omegax :=
	       coeff(collect(trans, [Der(x), Der(y)]), Der(x), 1);
	       omegay :=
	       coeff(collect(trans, [Der(x), Der(y)]), Der(y), 1);
	       trans2 := subs(omega,Der(x) = tt*Der(y) + y*Der(tt));
	       trans2 := subs(trans2,x = tt*y);
	       trans2 := subs(trans2,tt = x);
	       trans2 := collect(simplify(expand(trans2)/y^(mult + 1)),
				 [Der(x), Der(y)]);
	       omegax2 :=
	       coeff(collect(trans2, [Der(x), Der(y)]), Der(x), 1);
	       omegay2 :=
	       coeff(collect(trans2, [Der(x), Der(y)]), Der(y), 1);
#  the following change is made in order to make the divisor have always (x=0) as equation
it appears some three times within this proc.  #
	       omegax2 := subs(omegax2,x = uuu, y = vvv);
	       omegay2 := subs(omegay2,x = uuu, y = vvv);
	       omegax2 := subs(omegax2,uuu = y, vvv = x);
	       omegay2 := subs(omegay2,uuu = y, vvv = x);
#  end of the change, now the divisor is (x=0)   #
	       for i from 1 to nops(divv) do
		 textito:=textito."----" : end_for :
	       textito:=textito.">":
	       resol2::NUMDIVISOR:=resol2::NUMDIVISOR+1:nd:=resol2::NUMDIVISOR:
	       textito:=textito." Beginning divisor nr.: ".resol2::NUMDIVISOR." (dicritic)":
	       userinfo(1,textito):
#  If we are in a "regular" point (not a crossing) we add a new vertex to resol2::GRAFO and
connect it with the divisor under study 
minimo:=resol2::NUMDIVISOR:
when it is a corner, we have to place it between the one we are studying and the
MAXIMUM of its neighbors, "minimo" was a mistaken name( ;-).
The following lines are the same as below for non-dicritical points  #
	       if not(punto>0) then #  if not corner, add a vertex to resol2::GRAFO
                                         and connect it with the present divisor #
		 resol2::GRAFO:=AddVertex(resol2::GRAFO,[resol2::NUMDIVISOR]):
		 if not (punto=-11) then resol2::GRAFO:=
		 AddEdge(resol2::GRAFO,[ndd,resol2::NUMDIVISOR]): end_if;
	       end_if:
	       if punto>0 then #  if it is a corner, put new vertex between the present
                                    and the MAXIMUM of its neighbors
                                    do not be misled by the names(  ;-)  #
		 resol2::GRAFO:=AddVertex(resol2::GRAFO,resol2::NUMDIVISOR):
		 minimo:=max(seq((resol2::neighbors(ndd,resol2::GRAFO))[i],i=[$1..nops(
								       (resol2::neighbors(ndd,resol2::GRAFO)))])):
		 if not (minimo=0) #  I think this is now useless  #
		   then resol2::GRAFO:=resol2::anyadir(ndd,minimo,resol2::NUMDIVISOR,resol2::GRAFO):
		 else
		   resol2::GRAFO:=AddEdge(resol2::GRAFO,[ndd,resol2::NUMDIVISOR]):
		 end_if:
	       end_if:
#  graph changed, we begin to find singularities in the divisor  #
	       divv[nops(divv)]:= 1: #  to know that we have begun the study  #
#  first, the point at infinity  #
	       if subs(omegax2,y = 0,x=0) = 0 and subs(omegay2,y = 0,x=0) = 0
		 then divv[nops(divv)]:=2: #  useless?  #
		 resol2::reduccd(omegay2, omegax2, x, y, 1, "corner",
			 [seq(divv[d],d=[$1..nops(divv)])],0,ndd):
		 resol2::INF:=1: #  resol2::INF=1 means that the foliation is not solved after only one bl-up.  #
	       end_if;
#  the other chart: x=x', y=x'y' (points different from (x=0)) #
	       raices2 :=
	       solve(subs(omegay,x = 0)) intersect solve(subs(omegax,x = 0));
	       raices2 :=[seq(i,i=raices2)];print (Unquoted,raices2);
	       if 0 < nops(raices2) then resol2::INF:=1: #  same as before (5 lines up)  #
#  study the singularities in this chart #
		 rraices2:=raices2[1,1];
		 for ii from 1 to nops(raices2) do
#  we do not allow dicritic non-solvable roots (too messy for the user), but the
following conditional may be deleted if needed  #
		   if type(op(rraices2[ii],2))=RootOf then
		     userinfo(1, "there is a non-solvable polynomial. I have managed to do:",
			    [[seq(resol2::COCIENTES[i],i=[$1..(resol2::CONTADOR-1)])],
			     resol2::CONTADOR-1],resol2::GRAFO):
		     return(FAIL):
		   end_if:
		   omegax := collect(
				     expand(subs(y = y + op(raices2[ii],2), omegax)),
				     [x, y]);
		   omegay := collect(
				     expand(subs(y = y + op(raices2[ii],2), omegay)),
				     [x, y]);
#  the '0' at the end of this line means we are looking at a point in the divisor which is not
a crossing of invariant divisors  #
		   resol2::reduccd(omegax, omegay, x, y,0,
			   "regular",[seq(divv(d),d=[$1..nops(divv)]),0],ndd)
		 end_for:
	       end_if;
#  once finished, we announce the end of each divisor  #
	       textito:="";
	       for i from 1 to nops(divv) do textito:=textito."----" : end_for :
	       textito:="<".textito:
	       textito:=textito." End of divisor nr.: ".resol2::NUMDIVISOR." (dicritic)":
	       userinfo(1,textito):
#  now, if we have not needed to look at infinity (resol2::INF=0) and we are at (0,0) still (punto=-11),
this means that the foliations is a multiple of the radial, so we end at the first
blowing-up  #
	       if (punto=-11 and resol2::INF=0) then  return(["d1"],resol2::GRAFO):
	       end_if:
             else #  if inicial = 0  #
#  (if the tangent cone is not =0), we are at a  non-dicritical point and we have to study it.
First of all, check if it has multiplicity=1; if so, study the eigenvalues  #
	       if mult = 1 then autov := resol2::eigen2([[
						  coeff(collect(iny, [x, y]), x,1),
						  coeff(collect(iny, [x, y]), y,1)],
						 [-coeff(collect(inx, [x, y]), x,1),
						  -coeff(collect(inx, [x, y]), y,1)]])
	       end_if:
	       autov:=[seq(i,i=autov)];
#  if we are not at (0,0) (beginning), (punto=-11), then say wich kind of point it is  #
	       if not(punto=-11) then
		 userinfo(1,"Type of point: " . texto . " with multiplicity: " . mult . "\n"):
	       end_if:
#  if there is only one zero eigenvalue, the point is not simple (autov:=[1,1,1])  #
	       if autov = [0] or not (mult = 1) then
		 autov := [1, 1, 1]:cociente:=[]; #  to know that the point is not simple  #
	       else
#  if there is only one non-nil eigenvalue, then the quotient is 1  #
		 if nops(autov) = 1 then cociente := 1 #  to avoid errors  #
		 else
		   if autov[2] = 0 then cociente := 0 #  if one of the eigenv. is 0, the quotient is 0  #
		   else cociente := (autov[1]/autov[2]):
		   end_if:
		 end_if:
	       end_if:
#  resonant singularities (positive rational quotient are non-simple, so put autov:=[1,1,1]  #
	       if (mult=1 and (type(cociente)=DOM_INT or type(cociente)=DOM_RAT)) then
		 if cociente>0 then autov:=[1,1,1]: 
		   userinfo(1,"Resonant singulariry with quotient ",cociente,"\n");
		 end_if:
	       end_if:
#  end of the study of eigenvalues as such. Now, what to do if the singularity is simple?  #
	       if not (autov = [1, 1, 1]) then
#  if we are at the beginning (punto=-11), then end with a void graph and [0,cociente],
which means that the foliation is simple  #
		 if punto=-11 then return([[0,cociente],1])
		 end_if:
#  if punto<=0, that is, if we are not at a crossing of divisors, then we have
a separatrix. resol2::COCIENTES[resol2::CONTADOR]:=[0,cociente], where 0 means 'regular' point,
else resol2::COCIENTES[resol2::CONTADOR]:=[1,cociente], where 1 means 'corner' #
		 if punto<=0 then resol2::COCIENTES[resol2::CONTADOR] := [punto, cociente]:
		 else resol2::COCIENTES[resol2::CONTADOR] := [1,cociente]:
		 end_if:
		 textito:="Simple point with quotient ",cociente;
		 userinfo(1,textito):
#  resol2::CONTADOR is the number of simple singularities found  #
		 resol2::CONTADOR := resol2::CONTADOR + 1:
#  if punto=0, that is, we are at a regular point of the divisor,
give weight 'cociente' to the edge joining the divisor with the separatrix  #
		 if punto=0 then
#  notice that nops(divv)-1 is the number of the divisor under study: this is not true  #
		   nd:=nops(divv)-1:
		   resol2::GRAFO:=AddVertex(resol2::GRAFO,-resol2::SEP):resol2::GRAFO:=AddEdge(resol2::GRAFO,[ndd,-resol2::SEP],Eweight=cociente):
#  resol2::SEP is the number of separatrices found  #
		   resol2::SEP:=resol2::SEP+1:
#  now calculate the separatrix with present coordinates
with depth 5 by default  #
		   resol2::SEPARATRIX[resol2::SEP-1][1]:=t:
		   resol2::SEPARATRIX[resol2::SEP-1][2]:=0:
		   separatrix_par:=[resol2::SimpleSeparatrix([omegax,omegay],x,y,5)]:
		   j:=1:
		   while(type(separatrix_par[j][1])=DOM_INT) do
		     resol2::SEPARATRIX[resol2::SEP-1][2]:=resol2::SEPARATRIX[resol2::SEP-1][2]+
		     separatrix_par[j][2]*t^separatrix_par[j][1]:
		     j:=j+1:
		   end_while:
		   if separatrix_par[j][1]=infinity then resol2::SEPARATRIX[resol2::SEP-1][3]:="exact":
		   end_if:
		 else 
#  give weight cociente to edge of tree  #
#   #
#  if punto=1 and ndd=resol2::NUMDIVISOR, this means: we are looking at a corner appearing
in the last blowing-up. This corner joins ndd (our divisor) and the MAXIMUM of
its neighbors. Give weight 'cociente' to this edge of the graph  #
		   if punto=1 and ndd=resol2::NUMDIVISOR then
		     minimo:=max(seq((resol2::neighbors(ndd,resol2::GRAFO))[i],
				     i=[$1..nops((resol2::neighbors(ndd,resol2::GRAFO)))])):
#  the following conditional is only to refer to the proper edge: they are
always of the form [a,b] with a<b, but when a or b is a separatrix  #
		     if minimo<ndd then ChangeEdge(resol2::GRAFO,[minimo,ndd],Eweight=cociente):
		     else ChangeEdge(resol2::GRAFO,[minimo,ndd],Eweight=cociente)
		     end_if:
		   end_if:
#  we are not at the highest divisor or punto=2 (don't remember...), here the
corner joins ndd and the MINIMUM of its neighbors  #
		   if punto=2 or (punto=1 and not(ndd=resol2::NUMDIVISOR)) then
		     strange_thing:=resol2::neighbors(ndd,resol2::GRAFO);
#  if neighbors return exp(1), this means ndd has no neighbors, so we are at
the first divisor  #
		     if (not(type(strange_thing)=DOM_FLOAT)) then
		       Minim:=[seq((resol2::neighbors(ndd,resol2::GRAFO))[i],i=[$1..nops(
									 (resol2::neighbors(ndd,resol2::GRAFO)))])]:
		     else Minim:=[]; end_if:
		     minim:={}:i:=1;
#  compute the minimum  #
		     if not(type(Minim)=DOM_FLOAT) then
		       while not(i>nops(Minim)) do
			 if Minim[i]>0 then minim:=minim union {Minim[i]} end_if: i:=i+1;
		       end_while:
		     end_if:
		     minimo:=min(seq(i,i=minim)):
#  same as before, edges are [a,b] with a<b  #
		     if minimo<ndd then ChangeEdge(resol2::GRAFO,[minimo,ndd],Eweight=cociente):
		     else ChangeEdge(resol2::GRAFO,[minimo,ndd],Eweight=cociente)
		     end_if:
		   end_if: #  punto=2  #
		 end_if:  #  punto=0  #
	       else  #  not (autov=[1,1,1], that is, we are at a non-simple point: we blow-up.  #
#  add a divisor unless we are at the infinity of the first point (0,0)  #
		 if (divv[nops(divv)]=0) then
		   for i from 1 to nops(divv) do textito:=textito."----" : end_for :
		   textito:=textito.">":
		   resol2::NUMDIVISOR:=resol2::NUMDIVISOR+1:nd:=resol2::NUMDIVISOR:
		   textito:=textito." Beginning divisor nr.: ".resol2::NUMDIVISOR:
		   userinfo(1,textito):divv[nops(divv)]:=1:
		 end_if:
#  if we are not at a corner (punto=0), then add a vertex to resol2::GRAFO and
connect it with the present (resol2::NUMDIVISOR) divisor  #
		 if not(punto>0) then 
		   resol2::GRAFO:=AddVertex(resol2::GRAFO,[resol2::NUMDIVISOR]):
#  and unless we are looking at the infinity of (0,0), add the corresponding edge  #
		   if not (punto=-11) then resol2::GRAFO:=
		   AddEdge(resol2::GRAFO,[ndd,resol2::NUMDIVISOR]): end_if;
		 end_if:
#  if we are at a corner, place the new vertex between the present divisor
and the MAXIMUM of its neighbors (although the name is minimo...) #
		 if punto=1 then
		   resol2::GRAFO:=AddVertex(resol2::GRAFO,resol2::NUMDIVISOR):
		   minimo:=max(seq((resol2::neighbors(ndd,resol2::GRAFO))[i],
				   i=[$1..nops((resol2::neighbors(ndd,resol2::GRAFO)))])):
#  not sure, but this conditional seems useless  #
		   if not (minimo=0) then
		     userinfo(2,"I am going to add a divisor between ".ndd." and ". minimo):		     
		     resol2::GRAFO:=resol2::anyadir(ndd,minimo,resol2::NUMDIVISOR,resol2::GRAFO):
		   else
		     resol2::GRAFO:=AddEdge(resol2::GRAFO,[ndd,resol2::NUMDIVISOR]):
		   end_if:
		 end_if: #  punto =2  #
#now comes if punto = 1#
		 if punto=2 then
		   resol2::GRAFO:=AddVertex(resol2::GRAFO,resol2::NUMDIVISOR):
		   nbr:=resol2::neighbors(ndd,resol2::GRAFO):
		   print(nbr);
                   if not(type(nbr)=DOM_FLOAT) then
		   for iiii from 1 to nops(nbr) do if nbr[iiii]<0 then nbr[iiii]:=+infinity: end_if : end_for:
		   minimo:=min(seq((resol2::neighbors(ndd,resol2::GRAFO))[i],
				   i=[$1..nops((resol2::neighbors(ndd,resol2::GRAFO)))])):
                   else minimo:=0: end_if:
#  not sure, but this conditional seems useless  #
		   if not (minimo=0)
		     then
		     userinfo(2,"I am going to add a divisor between ".ndd." and ". minimo):
		     resol2::GRAFO:=resol2::anyadir(ndd,minimo,resol2::NUMDIVISOR,resol2::GRAFO):
		   else
		     resol2::GRAFO:=AddEdge(resol2::GRAFO,[ndd,resol2::NUMDIVISOR]):
		   end_if:
		 end_if: #  punto =1  #
#  graph changed, we begin the study of the new singular points: that is, we compute all
the singular points in the present divisor and blow-up all of them, 
always beginning with the chart x not 0  #
		 raices1 := solve(subs(inicial,x = 1), y):
		 raices1 := [seq(i,i=raices1)];
                       # atencion al renglon anterior "{...}" #
		 for i from 1 to nops(raices1) do
		   userinfo(1,"root: " ,raices1[i],  "\n"):
		   sep_before:=resol2::SEP:
		   trans1 := subs(omega,Der(y) = tt*Der(x) + raices1[i]*Der(x) + x*Der(tt));
		   trans1 := subs(trans1,y = x*tt + x*raices1[i]);
		   trans1 := subs(trans1,tt = y);
		   trans := collect(simplify(expand(trans1)/x^mult),[Der(x), Der(y)]);
		   trans := simplify(trans);
		   omegax := coeff(collect(trans, [Der(x), Der(y)]),
				   Der(x), 1);
		   omegay := coeff(collect(trans, [Der(x), Der(y)]),Der(y), 1);
#  end of blow-up   
three cases: the root is zero and the point is regular, the root is zero and
the point is a corner (this first one)-> this is "2", the root is not zero  #
		   if raices1[i] = 0 and punto >0 then
		     resol2::reduccd(omegax, omegay, x, y, 2, "corner",
			     [seq(divv[d],d=[$1..nops(divv)]),0],nd)
		   end_if:
#  regular point, zero root and we are not in the first blow-up,
hence, the new point is regular, this is "0".  #
		   if raices1[i]=0 and (punto <=0)
		     then
		     resol2::reduccd(omegax, omegay, x, y, 0, "regular",
			     [seq(divv[d],d=[$1..nops(divv)]),0],nd)
		   end_if:
#  in any other case, the new point is also regular.
I do not know if the first condition is useful (it was so during programation,
but nowadays it does not disturb). another "0"  #
		   if  not (raices1[i]= 0) then
		     resol2::reduccd(omegax, omegay, x, y, 0, "regular",
			     [seq(divv[d],d=[$1..nops(divv)]),0],nd)
		   end_if:
#  if we have found a separatrix in this path,
we have to "blow it up", that is, to project it
via the blowing-up we have done  #
		   if resol2::SEP>sep_before then
		     for j from sep_before to resol2::SEP-1 do
		       sx:=resol2::SEPARATRIX[j][1]:
		       sy:=resol2::SEPARATRIX[j][2]:
		       resol2::SEPARATRIX[j][1]:=sx:
		       resol2::SEPARATRIX[j][2]:=sy*sx+sx*raices1[i]:
		     end_for: #  i from sep_before+1 to sep  #
		   end_if: #  resol2::SEP > resol2::SEP_before  #		   
		 end_for; #  for i from 1 to nops(raices1)  #
	       end_if; #  not autov=[1,1,1]  #
#  end of the study of the points in the chart (x not 0), 
now for infinity (only look at it when the point is not regular):
bad programation, sorry  #
	       if  mult>0 then
		 if autov=[1,1,1] then
#  see if infinity is singular  #
		   if (subs(inicial,x= 0) = 0) then userinfo(1,"root: infinity\n"):
#  punto=-11 and resol2::INF =0 means "we are studying (0,0) and have not studied infinity yet"  #
		     sep_before:=resol2::SEP:
		     if ((punto=-11) and (resol2::INF=0)) then resol2::INF:=1: 
#  blow-up. This part is special for [0,0], but may be now it might be possible to eliminate it  #
		       trans := collect(expand(subs(subs(subs(omega,Der(x) = tt*Der(y) + y*Der(tt)),
							 x = tt*y),tt=x)/y^mult), [Der(x), Der(y)]);
		       omegax := coeff(collect(trans, [Der(x), Der(y)]),Der(x), 1);
		       omegay := coeff(collect(trans, [Der(x), Der(y)]),Der(y), 1);
		       omegax := subs(omegax,x = uuu, y = vvv);
		       omegay := subs(omegay,x = uuu, y = vvv);
		       omegax := subs(omegax,uuu = y, vvv = x);
		       omegay := subs(omegay,uuu = y, vvv = x);
#  blow-up ended, go to reduccd to begin again the study, "-1" means not new divisor, for
we are still at (0,0)  #
		       resol2::reduccd(omegay, omegax, x, y,-1, "regular",
			       [seq(divv[d],d=[$1..nops(divv)]),0],nd):
		     else
#  if the point is not [0,0], we blow up (as can be seen, I am not an expert programmer)  #
		       trans := collect(expand(subs(subs(subs(omega,Der(x) = tt*Der(y) + y*Der(tt))
							 ),x=tt*y),tt=x)/y^mult, [Der(x), Der(y)]);
		       trans:=simplify(subs(trans,tt=x));
		       omegax := coeff(collect(trans, [Der(x), Der(y)]),Der(x), 1);
		       omegay := coeff(collect(trans, [Der(x), Der(y)]),Der(y), 1);
		       omegax := subs(omegax,x = uuu, y = vvv);
		       omegay := subs(omegay,x = uuu, y = vvv);
		       omegax := subs(omegax,uuu = y, vvv = x);
		       omegay := subs(omegay,uuu = y, vvv = x);
#  blow-up ended, go to reduccd to begin again the study. "1" means new divisor created at a corner  #
		       resol2::reduccd(omegay, omegax, x, y, 1, "corner",
			       [seq(divv[d],d=[$1..nops(divv)]),0],nd): 
		     end_if: #  (if punto =-11 and resol2::INF=0)  #
#  if we have found a separatrix in this path,
we have to "blow it up", that is, to project it
via the blowing-up we have done  #
		     if resol2::SEP>sep_before then
		       for j from sep_before to resol2::SEP-1 do
			 sx:=resol2::SEPARATRIX[j][1]:
			 sy:=resol2::SEPARATRIX[j][2]:
			 resol2::SEPARATRIX[j][1]:=sy*sx:
			 resol2::SEPARATRIX[j][2]:=sx:
		       end_for: #  i from sep_before+1 to resol2::SEP  #
		     end_if: #  resol2::SEP > sep_before  #
		   end_if: #  (if subs(x=0,inicial)=0)  #
		 end_if: #  (if autov=[1,1,1])  #
	       end_if: #  (if mult>0)  #
	     end_if: #  (if inicial=0)  #
	     textito:="";
#  if we are finishing a divisor, tell the user so  #
	     if divv[nops(divv)]=1 then
	       for i from 1 to nops(divv) do textito:=textito."----" : end_for :
	       textito:="<".textito:
	       textito:=textito." End of  divisor nr.: ".nd:
	       userinfo(1,textito):
	     end_if:
#  the "2" now means: we have finished the divisor (nops(divv))  #
	     divv[nops(divv)]:=2;
	     return([[seq(resol2::COCIENTES[i],i=[$1..resol2::CONTADOR-1])],resol2::CONTADOR-1],
                                              resol2::GRAFO):
	   end_proc:
