#++
resol2::SimpleSeparatrix  - computes the separatrix of the form y=f(x) in a SIMPLE singularity
			      of a plane 1-form. If the singularity has two separatrices of that
                              kind, then it selects one (we only use it when (x=0) is the other
                              one)

resol2::SimpleSeparatrix(omega,varx,vary,depth)

omega   - the 1-form, a list of two polynomials [a,b]
varx    - the "x" variable
vary    - the "y" variable
depth   - the number of terms to compute
++#

#++
resol2::SimpleSeparatrix  - output

                   [[order.1,c.1],...,[order.depth,c.depth],<[infinity,0]>,<[0.0,0.0]>]

where
order.i    - the order of the i-th coefficient calculated
c.i        - the value of the i-th coefficient of the series expansion of the separatrix

depth      - is the parameter 'depth'

the optional terms, one (and only one) of which appears always, mean:
[infinity,0]   - the parametrization
                         (t,sum_{i=1}^{depth}(c.i*t^(order.i)) is a solution of omega

[0.0,0.0]      - the above parametrization is not a solution but only an approximation
++#
resol2::SimpleSeparatrix:=
proc (omega,varx,vary,depth)
  local omegax,omegay,x,y,newomegax,newomegay,newx,newy,order,bcoeff,a1,b1,c;
begin
  omegax:=omega[1]:
  omegay:=omega[2]:
  x:=varx:
  y:=vary:
/* if omega=adx+bdy has y as a factor in a, then y=0 is the solution, return */
  if iszero(subs(omegax,y=0)) then return([infinity,0]): end_if:
/* if depth=0 then we are done */
  if depth=0 then return([0.0,0.0]): end_if:
  bcoeff:=tcoeff(poly(subs(omegax,y=0),[x])):
  order:=ldegree(poly(subs(omegax,y=0),[x])):
  a1:=tcoeff(poly(subs(omegax,x=0),[y])):
  b1:=tcoeff(poly(subs(omegay,y=0),[x])):
  c:=-(bcoeff/(a1+b1*order)):
  newomegay:=subs(omegay,y=y+c*x^order):  
  newomegax:=subs(omegax,y=y+c*x^order)+c*order*x^(order-1)*newomegay:
  newx:=x:
  newy:=y+c*x^order:
  depth:=depth-1:
  return([order,c],resol2::SimpleSeparatrix([newomegax,newomegay],x,y,depth)):
end_proc: /* End of resol2::SimpleSeparatrix */

